@@ -25,13 +25,15 @@ import (
 	"reflect"
 	"strings"
 
+	"github.com/apache/camel-k/pkg/util"
+
 	"gopkg.in/yaml.v2"
 	"k8s.io/gengo/args"
 	"k8s.io/gengo/generator"
 	"k8s.io/gengo/types"
 )
 
-// traitMetaDataGen produces YAML documentation about trait descriptions
+// traitMetaDataGen produces YAML documentation about trait descriptions.
 type traitMetaDataGen struct {
 	generator.DefaultGen
 	arguments *args.GeneratorArgs
@@ -56,7 +58,7 @@ type traitPropertyMetaData struct {
 	Description string `yaml:"description"`
 }
 
-// NewtraitMetaDataGen --
+// NewtraitMetaDataGen --.
 func NewtraitMetaDataGen(arguments *args.GeneratorArgs) generator.Generator {
 	return &traitMetaDataGen{
 		DefaultGen: generator.DefaultGen{},
@@ -87,27 +89,24 @@ func (g *traitMetaDataGen) GenerateType(context *generator.Context, t *types.Typ
 	return nil
 }
 
-func (g *traitMetaDataGen) Finalize(c *generator.Context, w io.Writer) error {
+func (g *traitMetaDataGen) Finalize(c *generator.Context, w io.Writer) (err error) {
 	deployDir := g.arguments.CustomArgs.(*CustomArgs).ResourceDir
 	traitFile := "traits.yaml"
 	filename := path.Join(deployDir, traitFile)
 
-	var file *os.File
-	var err error
-	if file, err = os.OpenFile(filename, os.O_RDWR|os.O_CREATE, 0o777); err != nil {
-		return err
-	}
-	if err = file.Truncate(0); err != nil {
-		return err
-	}
-	defer file.Close()
+	return util.WithFile(filename, os.O_RDWR|os.O_CREATE, 0o777, func(file *os.File) error {
+		if err := file.Truncate(0); err != nil {
+			return err
+		}
 
-	data, err := yaml.Marshal(g.Root)
-	if err != nil {
-		fmt.Fprintf(file, "error: %v", err)
-	}
-	fmt.Fprintf(file, "%s", string(data))
-	return nil
+		data, err := yaml.Marshal(g.Root)
+		if err != nil {
+			fmt.Fprintf(file, "error: %v", err)
+		}
+		fmt.Fprintf(file, "%s", string(data))
+
+		return nil
+	})
 }
 
 func (g *traitMetaDataGen) getTraitID(t *types.Type) string {
@@ -125,7 +124,7 @@ func (g *traitMetaDataGen) getTraitID(t *types.Type) string {
 
 func (g *traitMetaDataGen) buildDescription(t *types.Type, traitID string, td *traitMetaData) {
 	desc := []string(nil)
-	desc = append(desc, g.filterOutTagsAndComments(t.CommentLines)...)
+	desc = append(desc, filterOutTagsAndComments(t.CommentLines)...)
 	td.Name = traitID
 	td.Description = ""
 	for _, line := range desc {
@@ -168,14 +167,3 @@ func (g *traitMetaDataGen) buildMembers(t *types.Type, content *[]string, td *tr
 		}
 	}
 }
-
-func (g *traitMetaDataGen) filterOutTagsAndComments(comments []string) []string {
-	res := make([]string, 0, len(comments))
-	for _, l := range comments {
-		if !strings.HasPrefix(strings.TrimLeft(l, " \t"), "+") &&
-			!strings.HasPrefix(strings.TrimLeft(l, " \t"), "TODO:") {
-			res = append(res, l)
-		}
-	}
-	return res
-}
