@@ -30,7 +30,7 @@ import (
 	k8serrors "k8s.io/apimachinery/pkg/api/errors"
 
 	"github.com/apache/camel-k/pkg/client"
-	camelv1 "github.com/apache/camel-k/pkg/client/camel/clientset/versioned/typed/camel/v1"
+	v1 "github.com/apache/camel-k/pkg/client/camel/clientset/versioned/typed/camel/v1"
 	"github.com/apache/camel-k/pkg/util/defaults"
 )
 
@@ -38,7 +38,7 @@ const kamelCommandLongDescription = `Apache Camel K is a lightweight integration
 superpowers.
 `
 
-// RootCmdOptions --
+// RootCmdOptions --.
 type RootCmdOptions struct {
 	RootContext   context.Context    `mapstructure:"-"`
 	Context       context.Context    `mapstructure:"-"`
@@ -48,7 +48,7 @@ type RootCmdOptions struct {
 	Namespace     string             `mapstructure:"namespace"`
 }
 
-// NewKamelCommand --
+// NewKamelCommand --.
 func NewKamelCommand(ctx context.Context) (*cobra.Command, error) {
 	childCtx, childCancel := context.WithCancel(ctx)
 	options := RootCmdOptions{
@@ -65,10 +65,6 @@ func NewKamelCommand(ctx context.Context) (*cobra.Command, error) {
 		return cmd, err
 	}
 
-	if err := addLocalSubCommands(cmd, &options); err != nil {
-		return cmd, err
-	}
-
 	err = kamelPostAddCommandInit(cmd)
 
 	return cmd, err
@@ -194,7 +190,7 @@ func (command *RootCmdOptions) preRun(cmd *cobra.Command, _ []string) error {
 		// reconciled. Hence the compatibility check is skipped for the install and the operator command.
 		// Furthermore, there can be any incompatibilities, as the install command deploys
 		// the operator version it's compatible with.
-		if cmd.Use != installCommand && cmd.Use != operatorCommand {
+		if cmd.Use != builderCommand && cmd.Use != installCommand && cmd.Use != operatorCommand {
 			checkAndShowCompatibilityWarning(command.Context, cmd, c, command.Namespace)
 		}
 	}
@@ -211,13 +207,13 @@ func checkAndShowCompatibilityWarning(ctx context.Context, cmd *cobra.Command, c
 			fmt.Fprintf(cmd.ErrOrStderr(), "Unable to retrieve the operator version: %s\n", err.Error())
 		}
 	} else {
-		if operatorVersion != "" && !compatibleVersions(operatorVersion, defaults.Version) {
+		if operatorVersion != "" && !compatibleVersions(operatorVersion, defaults.Version, cmd) {
 			fmt.Fprintf(cmd.ErrOrStderr(), "You're using Camel K %s client with a %s cluster operator, it's recommended to use the same version to improve compatibility.\n\n", defaults.Version, operatorVersion)
 		}
 	}
 }
 
-// GetCmdClient returns the client that can be used from command line tools
+// GetCmdClient returns the client that can be used from command line tools.
 func (command *RootCmdOptions) GetCmdClient() (client.Client, error) {
 	// Get the pre-computed client
 	if command._client != nil {
@@ -228,16 +224,16 @@ func (command *RootCmdOptions) GetCmdClient() (client.Client, error) {
 	return command._client, err
 }
 
-// GetCamelCmdClient returns a client to access the Camel resources
-func (command *RootCmdOptions) GetCamelCmdClient() (*camelv1.CamelV1Client, error) {
+// GetCamelCmdClient returns a client to access the Camel resources.
+func (command *RootCmdOptions) GetCamelCmdClient() (*v1.CamelV1Client, error) {
 	c, err := command.GetCmdClient()
 	if err != nil {
 		return nil, err
 	}
-	return camelv1.NewForConfig(c.GetConfig())
+	return v1.NewForConfig(c.GetConfig())
 }
 
-// NewCmdClient returns a new client that can be used from command line tools
+// NewCmdClient returns a new client that can be used from command line tools.
 func (command *RootCmdOptions) NewCmdClient() (client.Client, error) {
 	return client.NewOutOfClusterClient(command.KubeConfig)
 }
