@@ -27,12 +27,14 @@ import (
 
 	k8serrors "k8s.io/apimachinery/pkg/api/errors"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
+	"k8s.io/apimachinery/pkg/runtime/schema"
+	"k8s.io/apimachinery/pkg/runtime/serializer"
 
 	ctrl "sigs.k8s.io/controller-runtime/pkg/client"
+	"sigs.k8s.io/controller-runtime/pkg/client/apiutil"
 
 	"github.com/apache/camel-k/pkg/apis/camel/v1alpha1"
 	"github.com/apache/camel-k/pkg/client"
-	"github.com/apache/camel-k/pkg/util/kubernetes"
 	"github.com/apache/camel-k/pkg/util/olm"
 )
 
@@ -62,9 +64,9 @@ func newCmdUninstall(rootCmdOptions *RootCmdOptions) (*cobra.Command, *uninstall
 	cmd.Flags().Bool("skip-kamelets", false, "Do not uninstall the Kamelets in the current namespace")
 	cmd.Flags().Bool("global", false, "Indicates that a global installation is going to be uninstalled (affects OLM)")
 	cmd.Flags().Bool("olm", true, "Try to uninstall via OLM (Operator Lifecycle Manager) if available")
-	cmd.Flags().String("olm-operator-name", olm.DefaultOperatorName, "Name of the Camel K operator in the OLM source or marketplace")
-	cmd.Flags().String("olm-package", olm.DefaultPackage, "Name of the Camel K package in the OLM source or marketplace")
-	cmd.Flags().String("olm-global-namespace", olm.DefaultGlobalNamespace, "A namespace containing an OperatorGroup that defines "+
+	cmd.Flags().String("olm-operator-name", "", "Name of the Camel K operator in the OLM source or marketplace")
+	cmd.Flags().String("olm-package", "", "Name of the Camel K package in the OLM source or marketplace")
+	cmd.Flags().String("olm-global-namespace", "", "A namespace containing an OperatorGroup that defines "+
 		"global scope for the operator (used in combination with the --global flag)")
 	cmd.Flags().Bool("all", false, "Do uninstall all Camel K resources")
 
@@ -141,7 +143,7 @@ func (o *uninstallCmdOptions) uninstall(cmd *cobra.Command, _ []string) error {
 		fmt.Fprintf(cmd.OutOrStdout(), "Camel K Integration Platform removed from namespace %s\n", o.Namespace)
 	}
 
-	if err = o.uninstallNamespaceResources(o.Context, c); err != nil {
+	if err = o.uninstallNamespaceResources(o.Context, cmd, c); err != nil {
 		return err
 	}
 
@@ -153,11 +155,11 @@ func (o *uninstallCmdOptions) uninstall(cmd *cobra.Command, _ []string) error {
 			fmt.Fprintf(cmd.OutOrStdout(), "Camel K Operator removed from namespace %s\n", o.Namespace)
 		}
 
-		if err = o.uninstallNamespaceRoles(o.Context, c); err != nil {
+		if err = o.uninstallNamespaceRoles(o.Context, cmd, c); err != nil {
 			return err
 		}
 
-		if err = o.uninstallClusterWideResources(o.Context, c, o.Namespace); err != nil {
+		if err = o.uninstallClusterWideResources(o.Context, cmd, c, o.Namespace); err != nil {
 			return err
 		}
 
@@ -184,21 +186,21 @@ func (o *uninstallCmdOptions) uninstallOperator(ctx context.Context, c client.Cl
 	return nil
 }
 
-func (o *uninstallCmdOptions) uninstallClusterWideResources(ctx context.Context, c client.Client, namespace string) error {
+func (o *uninstallCmdOptions) uninstallClusterWideResources(ctx context.Context, cmd *cobra.Command, c client.Client, namespace string) error {
 	if !o.SkipCrd || o.UninstallAll {
 		if err := o.uninstallCrd(ctx, c); err != nil {
 			if k8serrors.IsForbidden(err) {
-				return createActionNotAuthorizedError()
+				return createActionNotAuthorizedError(cmd)
 			}
 			return err
 		}
-		fmt.Printf("Camel K Custom Resource Definitions removed from cluster\n")
+		fmt.Fprintln(cmd.OutOrStdout(), "Camel K Custom Resource Definitions removed from cluster")
 	}
 
 	if err := o.removeSubjectFromClusterRoleBindings(ctx, c, namespace); err != nil {
 		if k8serrors.IsForbidden(err) {
 			// Let's print a warning message and continue
-			fmt.Println("Current user is not authorized to remove the operator ServiceAccount from the cluster role bindings")
+			fmt.Fprintln(cmd.ErrOrStderr(), "Current user is not authorized to remove the operator ServiceAccount from the cluster role bindings")
 		} else if err != nil {
 			return err
 		}
@@ -207,78 +209,80 @@ func (o *uninstallCmdOptions) uninstallClusterWideResources(ctx context.Context,
 	if !o.SkipClusterRoleBindings || o.UninstallAll {
 		if err := o.uninstallClusterRoleBindings(ctx, c); err != nil {
 			if k8serrors.IsForbidden(err) {
-				return createActionNotAuthorizedError()
+				return createActionNotAuthorizedError(cmd)
 			}
 			return err
 		}
-		fmt.Printf("Camel K Cluster Role Bindings removed from cluster\n")
+		fmt.Fprintln(cmd.OutOrStdout(), "Camel K Cluster Role Bindings removed from cluster")
 	}
 
 	if !o.SkipClusterRoles || o.UninstallAll {
 		if err := o.uninstallClusterRoles(ctx, c); err != nil {
 			if k8serrors.IsForbidden(err) {
-				return createActionNotAuthorizedError()
+				return createActionNotAuthorizedError(cmd)
 			}
 			return err
 		}
-		fmt.Printf("Camel K Cluster Roles removed from cluster\n")
+		fmt.Fprintln(cmd.OutOrStdout(), "Camel K Cluster Roles removed from cluster")
 	}
 
 	return nil
 }
 
-func (o *uninstallCmdOptions) uninstallNamespaceRoles(ctx context.Context, c client.Client) error {
+func (o *uninstallCmdOptions) uninstallNamespaceRoles(ctx context.Context, cmd *cobra.Command, c client.Client) error {
 	if !o.SkipRoleBindings {
 		if err := o.uninstallRoleBindings(ctx, c); err != nil {
 			return err
 		}
-		fmt.Printf("Camel K Role Bindings removed from namespace %s\n", o.Namespace)
+		fmt.Fprintln(cmd.OutOrStdout(), "Camel K Role Bindings removed from namespace", o.Namespace)
 	}
 
 	if !o.SkipRoles {
 		if err := o.uninstallRoles(ctx, c); err != nil {
 			return err
 		}
-		fmt.Printf("Camel K Roles removed from namespace %s\n", o.Namespace)
+		fmt.Fprintln(cmd.OutOrStdout(), "Camel K Roles removed from namespace", o.Namespace)
 	}
 
 	if !o.SkipServiceAccounts {
 		if err := o.uninstallServiceAccounts(ctx, c); err != nil {
 			return err
 		}
-		fmt.Printf("Camel K Service Accounts removed from namespace %s\n", o.Namespace)
+		fmt.Fprintln(cmd.OutOrStdout(), "Camel K Service Accounts removed from namespace", o.Namespace)
 	}
 
 	return nil
 }
 
-func (o *uninstallCmdOptions) uninstallNamespaceResources(ctx context.Context, c client.Client) error {
+func (o *uninstallCmdOptions) uninstallNamespaceResources(ctx context.Context, cmd *cobra.Command, c client.Client) error {
 	if !o.SkipConfigMaps {
 		if err := o.uninstallConfigMaps(ctx, c); err != nil {
 			return err
 		}
-		fmt.Printf("Camel K Config Maps removed from namespace %s\n", o.Namespace)
+		fmt.Fprintln(cmd.OutOrStdout(), "Camel K Config Maps removed from namespace", o.Namespace)
 	}
 
 	if !o.SkipRegistrySecret {
 		if err := o.uninstallRegistrySecret(ctx, c); err != nil {
 			return err
 		}
-		fmt.Printf("Camel K Registry Secret removed from namespace %s\n", o.Namespace)
+		fmt.Fprintln(cmd.OutOrStdout(), "Camel K Registry Secret removed from namespace", o.Namespace)
 	}
 
 	if !o.SkipKamelets {
 		if err := o.uninstallKamelets(ctx, c); err != nil {
 			return err
 		}
-		fmt.Printf("Camel K platform Kamelets removed from namespace %s\n", o.Namespace)
+		fmt.Fprintln(cmd.OutOrStdout(), "Camel K platform Kamelets removed from namespace", o.Namespace)
 	}
 
 	return nil
 }
 
 func (o *uninstallCmdOptions) uninstallCrd(ctx context.Context, c client.Client) error {
-	restClient, err := kubernetes.GetClientFor(c, "apiextensions.k8s.io", "v1")
+	restClient, err := apiutil.RESTClientForGVK(
+		schema.GroupVersionKind{Group: "apiextensions.k8s.io", Version: "v1"}, false,
+		c.GetConfig(), serializer.NewCodecFactory(c.GetScheme()))
 	if err != nil {
 		return err
 	}
@@ -359,12 +363,11 @@ func (o *uninstallCmdOptions) removeSubjectFromClusterRoleBindings(ctx context.C
 	}
 
 	// Remove the subject corresponding to this operator install
-	for _, clusterRoleBinding := range clusterRoleBindings.Items {
+	for crbIndex, clusterRoleBinding := range clusterRoleBindings.Items {
 		for i, subject := range clusterRoleBinding.Subjects {
 			if subject.Name == "camel-k-operator" && subject.Namespace == namespace {
 				clusterRoleBinding.Subjects = append(clusterRoleBinding.Subjects[:i], clusterRoleBinding.Subjects[i+1:]...)
-				crb := &clusterRoleBinding
-				_, err = api.ClusterRoleBindings().Update(ctx, crb, metav1.UpdateOptions{})
+				_, err = api.ClusterRoleBindings().Update(ctx, &clusterRoleBindings.Items[crbIndex], metav1.UpdateOptions{})
 				if err != nil {
 					return err
 				}
@@ -470,10 +473,10 @@ func (o *uninstallCmdOptions) uninstallKamelets(ctx context.Context, c client.Cl
 		return err
 	}
 
-	for _, kamelet := range kameletList.Items {
+	for i := range kameletList.Items {
 		// remove only platform Kamelets (use-defined Kamelets should be skipped)
-		if kamelet.Labels[v1alpha1.KameletBundledLabel] == "true" {
-			err := c.Delete(ctx, &kamelet)
+		if kameletList.Items[i].Labels[v1alpha1.KameletBundledLabel] == "true" {
+			err := c.Delete(ctx, &kameletList.Items[i])
 			if err != nil {
 				return err
 			}
@@ -483,8 +486,8 @@ func (o *uninstallCmdOptions) uninstallKamelets(ctx context.Context, c client.Cl
 	return nil
 }
 
-func createActionNotAuthorizedError() error {
-	fmt.Println("Current user is not authorized to remove cluster-wide objects like custom resource definitions or cluster roles")
+func createActionNotAuthorizedError(cmd *cobra.Command) error {
+	fmt.Fprintln(cmd.ErrOrStderr(), "Current user is not authorized to remove cluster-wide objects like custom resource definitions or cluster roles")
 	msg := `login as cluster-admin and execute "kamel uninstall" or use flags "--skip-crd --skip-cluster-roles --skip-cluster-role-bindings"`
 	return errors.New(msg)
 }
