@@ -20,8 +20,10 @@ package cmd
 import (
 	"context"
 	"fmt"
+	"strings"
 
 	"github.com/Masterminds/semver"
+	"github.com/fatih/camelcase"
 	"github.com/spf13/cobra"
 
 	k8sclient "sigs.k8s.io/controller-runtime/pkg/client"
@@ -31,9 +33,13 @@ import (
 	"github.com/apache/camel-k/pkg/util/defaults"
 )
 
-// VersionVariant may be overridden at build time
+// VersionVariant may be overridden at build time.
 var VersionVariant = ""
 
+const (
+	infoVersion = "Version"
+)
+
 func newCmdVersion(rootCmdOptions *RootCmdOptions) (*cobra.Command, *versionCmdOptions) {
 	options := versionCmdOptions{
 		RootCmdOptions: rootCmdOptions,
@@ -50,6 +56,8 @@ func newCmdVersion(rootCmdOptions *RootCmdOptions) (*cobra.Command, *versionCmdO
 	}
 
 	cmd.Flags().Bool("operator", false, "Display Operator version")
+	cmd.Flags().BoolP("verbose", "v", false, "Display all available extra information")
+	cmd.Flags().BoolP("all", "a", false, "Display both Client and Operator version")
 
 	return &cmd, &options
 }
@@ -57,10 +65,12 @@ func newCmdVersion(rootCmdOptions *RootCmdOptions) (*cobra.Command, *versionCmdO
 type versionCmdOptions struct {
 	*RootCmdOptions
 	Operator bool `mapstructure:"operator"`
+	Verbose  bool `mapstructure:"verbose"`
+	All      bool `mapstructure:"all"`
 }
 
 func (o *versionCmdOptions) preRunE(cmd *cobra.Command, args []string) error {
-	if !o.Operator {
+	if !o.Operator && !o.All {
 		// let the command to work in offline mode
 		cmd.Annotations[offlineCommandLabel] = "true"
 	}
@@ -68,40 +78,58 @@ func (o *versionCmdOptions) preRunE(cmd *cobra.Command, args []string) error {
 }
 
 func (o *versionCmdOptions) run(cmd *cobra.Command, _ []string) error {
-	if o.Operator {
+	if o.All || !o.Operator {
+		o.displayClientVersion(cmd)
+	}
+	if o.All {
+		// breaking line
+		fmt.Fprintln(cmd.OutOrStdout(), "")
+	}
+	if o.All || o.Operator {
 		c, err := o.GetCmdClient()
 		if err != nil {
 			return err
 		}
-		displayOperatorVersion(o.Context, cmd, c, o.Namespace)
-	} else {
-		displayClientVersion(cmd)
+		o.displayOperatorVersion(cmd, c)
 	}
 	return nil
 }
 
-func displayClientVersion(cmd *cobra.Command) {
+func (o *versionCmdOptions) displayClientVersion(cmd *cobra.Command) {
 	if VersionVariant != "" {
 		fmt.Fprintf(cmd.OutOrStdout(), "Camel K Client %s %s\n", VersionVariant, defaults.Version)
 	} else {
 		fmt.Fprintf(cmd.OutOrStdout(), "Camel K Client %s\n", defaults.Version)
 	}
+	if o.Verbose {
+		fmt.Fprintf(cmd.OutOrStdout(), "Git Commit: %s\n", defaults.GitCommit)
+	}
 }
 
-func displayOperatorVersion(ctx context.Context, cmd *cobra.Command, c client.Client, namespace string) {
-	operatorVersion, err := operatorVersion(ctx, c, namespace)
+func (o *versionCmdOptions) displayOperatorVersion(cmd *cobra.Command, c client.Client) {
+	operatorInfo, err := operatorInfo(o.Context, c, o.Namespace)
 	if err != nil {
 		fmt.Fprintf(cmd.OutOrStdout(), "Unable to retrieve operator version: %s\n", err)
 	} else {
-		if operatorVersion == "" {
+		if operatorInfo[infoVersion] == "" {
 			fmt.Fprintf(cmd.OutOrStdout(), "Unable to retrieve operator version: The IntegrationPlatform resource hasn't been reconciled yet!")
 		} else {
-			fmt.Fprintf(cmd.OutOrStdout(), "Camel K Operator %s\n", operatorVersion)
+			fmt.Fprintf(cmd.OutOrStdout(), "Camel K Operator %s\n", operatorInfo[infoVersion])
+
+			if o.Verbose {
+				for k, v := range operatorInfo {
+					if k != infoVersion {
+						fmt.Fprintf(cmd.OutOrStdout(), "%s: %s\n", k, v)
+					}
+				}
+			}
 		}
 	}
 }
 
-func operatorVersion(ctx context.Context, c client.Client, namespace string) (string, error) {
+func operatorInfo(ctx context.Context, c client.Client, namespace string) (map[string]string, error) {
+	infos := make(map[string]string)
+
 	platform := v1.NewIntegrationPlatform(namespace, "camel-k")
 	platformKey := k8sclient.ObjectKey{
 		Namespace: namespace,
@@ -109,21 +137,49 @@ func operatorVersion(ctx context.Context, c client.Client, namespace string) (st
 	}
 
 	if err := c.Get(ctx, platformKey, &platform); err != nil {
-		return "", err
+		return nil, err
+	}
+	// Useful information
+	infos["version"] = platform.Status.Version
+	infos["publishStrategy"] = string(platform.Status.Build.PublishStrategy)
+	infos["runtimeVersion"] = platform.Status.Build.RuntimeVersion
+
+	if platform.Status.Info != nil {
+		for k, v := range platform.Status.Info {
+			infos[k] = v
+		}
 	}
 
-	return platform.Status.Version, nil
+	return fromCamelCase(infos), nil
 }
 
-func compatibleVersions(aVersion, bVersion string) bool {
+func fromCamelCase(infos map[string]string) map[string]string {
+	textKeys := make(map[string]string)
+	for k, v := range infos {
+		key := strings.Title(strings.Join(camelcase.Split(k), " "))
+		textKeys[key] = v
+	}
+
+	return textKeys
+}
+
+func operatorVersion(ctx context.Context, c client.Client, namespace string) (string, error) {
+	infos, err := operatorInfo(ctx, c, namespace)
+	if err != nil {
+		return "", err
+	}
+	return infos[infoVersion], nil
+}
+
+func compatibleVersions(aVersion, bVersion string, cmd *cobra.Command) bool {
 	a, err := semver.NewVersion(aVersion)
 	if err != nil {
-		fmt.Printf("Could not parse %s (error: %s)\n", a, err)
+		fmt.Fprintln(cmd.ErrOrStderr(), "Could not parse '"+aVersion+"' (error:", err.Error()+")")
 		return false
 	}
 	b, err := semver.NewVersion(bVersion)
 	if err != nil {
-		fmt.Printf("Could not parse %s (error: %s)\n", b, err)
+		fmt.Fprintln(cmd.ErrOrStderr(), "Could not parse '"+bVersion+"' (error:", err.Error()+")")
 		return false
 	}
 	// We consider compatible when major and minor are equals
