@@ -26,12 +26,13 @@ import (
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 
 	v1 "github.com/apache/camel-k/pkg/apis/camel/v1"
+	"github.com/apache/camel-k/pkg/builder"
 	"github.com/apache/camel-k/pkg/client"
 	platformutil "github.com/apache/camel-k/pkg/platform"
 	"github.com/apache/camel-k/pkg/util/defaults"
 )
 
-// NewInitializeAction returns a action that initializes the platform configuration when not provided by the user
+// NewInitializeAction returns a action that initializes the platform configuration when not provided by the user.
 func NewInitializeAction() Action {
 	return &initializeAction{}
 }
@@ -68,9 +69,13 @@ func (action *initializeAction) Handle(ctx context.Context, platform *v1.Integra
 	if err = platformutil.ConfigureDefaults(ctx, action.client, platform, true); err != nil {
 		return nil, err
 	}
-
+	// nolint: staticcheck
 	if platform.Status.Build.PublishStrategy == v1.IntegrationPlatformBuildPublishStrategyKaniko {
-		if platform.Status.Build.IsKanikoCacheEnabled() {
+		cacheEnabled := platform.Status.Build.IsOptionEnabled(builder.KanikoBuildCacheEnabled)
+		if _, found := platform.Status.Build.PublishStrategyOptions[builder.KanikoBuildCacheEnabled]; !found {
+			cacheEnabled = *platform.Status.Build.KanikoBuildCache
+		}
+		if cacheEnabled {
 			// Create the persistent volume claim used by the Kaniko cache
 			action.L.Info("Create persistent volume claim")
 			err := createPersistentVolumeClaim(ctx, action.client, platform)
@@ -120,6 +125,11 @@ func createPersistentVolumeClaim(ctx context.Context, client client.Client, plat
 	if err != nil {
 		return err
 	}
+	// nolint: staticcheck
+	pvcName := platform.Status.Build.PersistentVolumeClaim
+	if persistentVolumeClaim, found := platform.Status.Build.PublishStrategyOptions[builder.KanikoPVCName]; found {
+		pvcName = persistentVolumeClaim
+	}
 
 	pvc := &corev1.PersistentVolumeClaim{
 		TypeMeta: metav1.TypeMeta{
@@ -128,7 +138,7 @@ func createPersistentVolumeClaim(ctx context.Context, client client.Client, plat
 		},
 		ObjectMeta: metav1.ObjectMeta{
 			Namespace: platform.Namespace,
-			Name:      platform.Status.Build.PersistentVolumeClaim,
+			Name:      pvcName,
 			Labels: map[string]string{
 				"app": "camel-k",
 			},
