@@ -21,9 +21,10 @@ import (
 	"context"
 
 	"github.com/apache/camel-k/pkg/apis/camel/v1alpha1"
+	kameletutils "github.com/apache/camel-k/pkg/kamelet"
 )
 
-// NewMonitorAction returns an action that monitors the kamelet after it's fully initialized
+// NewMonitorAction returns an action that monitors the kamelet after it's fully initialized.
 func NewMonitorAction() Action {
 	return &monitorAction{}
 }
@@ -37,9 +38,9 @@ func (action *monitorAction) Name() string {
 }
 
 func (action *monitorAction) CanHandle(kamelet *v1alpha1.Kamelet) bool {
-	return kamelet.Status.Phase == v1alpha1.KameletPhaseReady
+	return kamelet.Status.Phase == v1alpha1.KameletPhaseReady || kamelet.Status.Phase == v1alpha1.KameletPhaseError
 }
 
 func (action *monitorAction) Handle(ctx context.Context, kamelet *v1alpha1.Kamelet) (*v1alpha1.Kamelet, error) {
-	return updateStatus(kamelet)
+	return kameletutils.Initialize(kamelet)
 }
