@@ -35,6 +35,7 @@ import (
 
 	"github.com/apache/camel-k/pkg/client"
 	"github.com/apache/camel-k/pkg/resources"
+	"github.com/apache/camel-k/pkg/util/knative"
 	"github.com/apache/camel-k/pkg/util/kubernetes"
 )
 
@@ -176,6 +177,12 @@ func SetupClusterWideResourcesOrCollect(ctx context.Context, clientProvider clie
 		}
 	}
 
+	ok, err = isClusterRoleInstalled(ctx, c, "camel-k-operator-local-registry")
+	if err == nil && !ok {
+		// nolint: errcheck
+		installResource(ctx, c, collection, "/rbac/operator-cluster-role-local-registry.yaml")
+	}
+
 	isOpenShift, err := isOpenShift(c, clusterType)
 	if err != nil {
 		return err
@@ -193,6 +200,23 @@ func SetupClusterWideResourcesOrCollect(ctx context.Context, clientProvider clie
 		}
 	}
 
+	isKnative, err := knative.IsInstalled(ctx, c)
+	if err != nil {
+		return err
+	}
+	if isKnative {
+		ok, err := isClusterRoleInstalled(ctx, c, "camel-k-operator-bind-addressable-resolver")
+		if err != nil {
+			return err
+		}
+		if !ok || collection != nil {
+			err := installResource(ctx, c, collection, "/rbac/operator-cluster-role-addressable-resolver.yaml")
+			if err != nil {
+				return err
+			}
+		}
+	}
+
 	return nil
 }
 
@@ -268,7 +292,12 @@ func isCrdInstalled(c client.Client, kind string, version string) (bool, error)
 }
 
 func installCRD(ctx context.Context, c client.Client, kind string, version string, resourceName string, converter ResourceCustomizer, collection *kubernetes.Collection, force bool) error {
-	crd, err := kubernetes.LoadResourceFromYaml(c.GetScheme(), resources.ResourceAsString("/crd/bases/"+resourceName))
+	content, err := resources.ResourceAsString("/crd/bases/" + resourceName)
+	if err != nil {
+		return err
+	}
+
+	crd, err := kubernetes.LoadResourceFromYaml(c.GetScheme(), content)
 	if err != nil {
 		return err
 	}
@@ -319,7 +348,12 @@ func isResourceInstalled(ctx context.Context, c client.Client, object ctrl.Objec
 }
 
 func installResource(ctx context.Context, c client.Client, collection *kubernetes.Collection, resource string) error {
-	obj, err := kubernetes.LoadResourceFromYaml(c.GetScheme(), resources.ResourceAsString(resource))
+	content, err := resources.ResourceAsString(resource)
+	if err != nil {
+		return err
+	}
+
+	obj, err := kubernetes.LoadResourceFromYaml(c.GetScheme(), content)
 	if err != nil {
 		return err
 	}
