@@ -32,7 +32,7 @@ import (
 // The builder trait is internally used to determine the best strategy to
 // build and configure IntegrationKits.
 //
-// +camel-k:trait=builder
+// +camel-k:trait=builder.
 type builderTrait struct {
 	BaseTrait `property:",squash"`
 	// Enable verbose logging on build components that support it (e.g. Kaniko build pod).
@@ -47,12 +47,12 @@ func newBuilderTrait() Trait {
 	}
 }
 
-// IsPlatformTrait overrides base class method
+// IsPlatformTrait overrides base class method.
 func (t *builderTrait) IsPlatformTrait() bool {
 	return true
 }
 
-// InfluencesKit overrides base class method
+// InfluencesKit overrides base class method.
 func (t *builderTrait) InfluencesKit() bool {
 	return true
 }
@@ -109,11 +109,21 @@ func (t *builderTrait) Apply(e *Environment) error {
 				Image:    getImageName(e),
 				Registry: e.Platform.Status.Build.Registry,
 			},
-			HttpProxySecret: e.Platform.Status.Build.HTTPProxySecret,
-			Verbose:         t.Verbose,
+			Verbose: t.Verbose,
 		}})
-
+	// nolint: staticcheck
 	case v1.IntegrationPlatformBuildPublishStrategyKaniko:
+		var persistentVolumeClaim string
+		var found, cacheEnabled bool
+		if persistentVolumeClaim, found = e.Platform.Status.Build.PublishStrategyOptions[builder.KanikoPVCName]; !found {
+			persistentVolumeClaim = e.Platform.Status.Build.PersistentVolumeClaim
+		}
+
+		cacheEnabled = e.Platform.Status.Build.IsOptionEnabled(builder.KanikoBuildCacheEnabled)
+		if _, found = e.Platform.Status.Build.PublishStrategyOptions[builder.KanikoBuildCacheEnabled]; !found {
+			cacheEnabled = *e.Platform.Status.Build.KanikoBuildCache
+		}
+
 		e.BuildTasks = append(e.BuildTasks, v1.Task{Kaniko: &v1.KanikoTask{
 			BaseTask: v1.BaseTask{
 				Name: "kaniko",
@@ -123,11 +133,10 @@ func (t *builderTrait) Apply(e *Environment) error {
 				Registry: e.Platform.Status.Build.Registry,
 			},
 			Cache: v1.KanikoTaskCache{
-				Enabled:               e.Platform.Status.Build.KanikoBuildCache,
-				PersistentVolumeClaim: e.Platform.Status.Build.PersistentVolumeClaim,
+				Enabled:               &cacheEnabled,
+				PersistentVolumeClaim: persistentVolumeClaim,
 			},
-			HttpProxySecret: e.Platform.Status.Build.HTTPProxySecret,
-			Verbose:         t.Verbose,
+			Verbose: t.Verbose,
 		}})
 	}
 
@@ -135,8 +144,9 @@ func (t *builderTrait) Apply(e *Environment) error {
 }
 
 func (t *builderTrait) builderTask(e *Environment) (*v1.BuilderTask, error) {
-	maven := e.Platform.Status.Build.Maven
-
+	maven := v1.MavenBuildSpec{
+		MavenSpec: e.Platform.Status.Build.Maven,
+	}
 	// Add Maven repositories defined in the IntegrationKit
 	for _, repo := range e.IntegrationKit.Spec.Repositories {
 		maven.Repositories = append(maven.Repositories, mvn.NewRepository(repo))
