@@ -29,7 +29,7 @@ import (
 
 // The PDB trait allows to configure the PodDisruptionBudget resource for the Integration pods.
 //
-// +camel-k:trait=pdb
+// +camel-k:trait=pdb.
 type pdbTrait struct {
 	BaseTrait `property:",squash"`
 	// The number of pods for the Integration that must still be available after an eviction.
@@ -66,10 +66,7 @@ func (t *pdbTrait) Configure(e *Environment) (bool, error) {
 		return false, fmt.Errorf("both minAvailable and maxUnavailable can't be set simultaneously")
 	}
 
-	return e.IntegrationInPhase(
-		v1.IntegrationPhaseDeploying,
-		v1.IntegrationPhaseRunning,
-	), nil
+	return e.IntegrationInRunningPhases(), nil
 }
 
 func (t *pdbTrait) Apply(e *Environment) error {
