@@ -27,18 +27,27 @@ import (
 	"github.com/apache/camel-k/pkg/util/camel"
 )
 
-func TestConfigureQuarkusTraitShouldSucceed(t *testing.T) {
+func TestConfigureQuarkusTraitBuildSubmitted(t *testing.T) {
 	quarkusTrait, environment := createNominalQuarkusTest()
+	environment.IntegrationKit.Status.Phase = v1.IntegrationKitPhaseBuildSubmitted
 
 	configured, err := quarkusTrait.Configure(environment)
 
 	assert.True(t, configured)
 	assert.Nil(t, err)
+
+	err = quarkusTrait.Apply(environment)
+	assert.Nil(t, err)
+
+	build := getBuilderTask(environment.BuildTasks)
+	assert.NotNil(t, t, build)
+
+	assert.Len(t, build.Steps, len(builder.Quarkus.CommonSteps)+3)
 }
 
 func TestConfigureDisabledQuarkusTraitShouldFail(t *testing.T) {
 	quarkusTrait, environment := createNominalQuarkusTest()
-	quarkusTrait.Enabled = new(bool)
+	quarkusTrait.Enabled = BoolP(false)
 
 	configured, err := quarkusTrait.Configure(environment)
 
@@ -46,29 +55,23 @@ func TestConfigureDisabledQuarkusTraitShouldFail(t *testing.T) {
 	assert.Nil(t, err)
 }
 
-func TestApplyQuarkusTraitDoesNothing(t *testing.T) {
+func TestApplyQuarkusTraitDefaultKitLayout(t *testing.T) {
 	quarkusTrait, environment := createNominalQuarkusTest()
+	environment.Integration.Status.Phase = v1.IntegrationPhaseBuildingKit
 
-	err := quarkusTrait.Apply(environment)
-
+	configured, err := quarkusTrait.Configure(environment)
+	assert.True(t, configured)
 	assert.Nil(t, err)
-}
 
-func TestQuarkusTraitAddBuildStepsShouldSucceed(t *testing.T) {
-	quarkusTrait, _ := createNominalQuarkusTest()
-
-	steps := make([]builder.Step, 0)
-	steps = append(steps, builder.DefaultSteps...)
-
-	quarkusTrait.addBuildSteps(&steps)
-
-	assert.Len(t, steps, len(builder.DefaultSteps)+len(builder.QuarkusSteps))
+	err = quarkusTrait.Apply(environment)
+	assert.Nil(t, err)
+	assert.Len(t, environment.IntegrationKits, 1)
+	assert.Equal(t, environment.IntegrationKits[0].Labels[v1.IntegrationKitLayoutLabel], v1.IntegrationKitLayoutFastJar)
 }
 
 func createNominalQuarkusTest() (*quarkusTrait, *Environment) {
-	trait := newQuarkusTrait().(*quarkusTrait)
-	enabled := true
-	trait.Enabled = &enabled
+	trait, _ := newQuarkusTrait().(*quarkusTrait)
+	trait.Enabled = BoolP(true)
 
 	environment := &Environment{
 		CamelCatalog: &camel.RuntimeCatalog{},
@@ -81,6 +84,12 @@ func createNominalQuarkusTest() (*quarkusTrait, *Environment) {
 				},
 			},
 		},
+		IntegrationKit: &v1.IntegrationKit{},
+		BuildTasks: []v1.Task{
+			{
+				Builder: &v1.BuilderTask{},
+			},
+		},
 		Platform: &v1.IntegrationPlatform{},
 	}
 
